@@ -21,6 +21,16 @@ class Config(Base):
     notifications_token = sa.Column(sa.VARCHAR(1000), default='')
     otp_secret = sa.Column(sa.VARCHAR(50), default='')
     password = sa.Column(sa.VARCHAR(150), default='')
+    scratchspace_dir = sa.Column(sa.VARCHAR(250), default='~/Scratchspace')
+    slack_url = sa.Column(sa.VARCHAR(500), default='')
+    smtp_email_from = sa.Column(sa.VARCHAR(250), default='')
+    smtp_password = sa.Column(sa.VARCHAR(250), default='')
+    smtp_port = sa.Column(sa.INTEGER, default=465)
+    smtp_server = sa.Column(sa.VARCHAR(250), default='')
+    smtp_email_to = sa.Column(sa.VARCHAR(250), default='')
+    smtp_username = sa.Column(sa.VARCHAR(250), default='')
+    smtp_starttls = sa.Column(sa.BOOLEAN, default=True)
     template_dir = sa.Column(sa.VARCHAR(250), default='~/Templates')
     user_id = sa.Column(sa.VARCHAR(20), default='')
     use_proxies = sa.Column(sa.BOOLEAN, default=False)
+    use_scratchspace = sa.Column(sa.BOOLEAN, default=False)
