@@ -223,6 +223,60 @@ class TargetsTestCase(unittest.TestCase):
         self.assertEqual([cat1], self.targets.get_assessments())
         self.targets.db.add_categories.assert_called_with(assessments)
 
+    def test_get_attachments_current(self):
+        """Should return a list of attachments based on currently selected target"""
+        attachments = [
+            {
+                "listing_id": "12uib",
+                "url": "https://www.download.com/uh1g23ri",
+                "filename": "file1.txt",
+                "created_at": 1667840052,
+                "updated_at": 1667849178,
+            }
+        ]
+        self.targets.get_connected = MagicMock()
+        self.targets.get_connected.return_value = {'codename': 'TASTYTACO', 'slug': 'u2ire'}
+        self.targets.db.find_targets = MagicMock()
+        self.targets.db.find_targets.return_value = [Target(slug='u2ire')]
+        self.targets.api.request.return_value.status_code = 200
+        self.targets.api.request.return_value.json.return_value = attachments
+        self.assertEquals(self.targets.get_attachments(), attachments)
+        self.targets.api.request.assert_called_with('GET', 'targets/u2ire/resources')
+
+    def test_get_attachments_slug(self):
+        """Should return a list of attachments given a slug"""
+        attachments = [
+            {
+                "listing_id": "12uib",
+                "url": "https://www.download.com/uh1g23ri",
+                "filename": "file1.txt",
+                "created_at": 1667840052,
+                "updated_at": 1667849178,
+            }
+        ]
+        self.targets.db.find_targets = MagicMock()
+        self.targets.db.find_targets.return_value = [Target(slug='u2ire')]
+        self.targets.api.request.return_value.status_code = 200
+        self.targets.api.request.return_value.json.return_value = attachments
+        self.assertEquals(self.targets.get_attachments(slug='u2ire'), attachments)
+        self.targets.api.request.assert_called_with('GET', 'targets/u2ire/resources')
+
+    def test_get_attachments_target(self):
+        """Should return a list of attachments given a Target"""
+        attachments = [
+            {
+                "listing_id": "12uib",
+                "url": "https://www.download.com/uh1g23ri",
+                "filename": "file1.txt",
+                "created_at": 1667840052,
+                "updated_at": 1667849178,
+            }
+        ]
+        self.targets.api.request.return_value.status_code = 200
+        self.targets.api.request.return_value.json.return_value = attachments
+        self.assertEquals(self.targets.get_attachments(target=Target(slug='u2ire')), attachments)
+        self.targets.api.request.assert_called_with('GET', 'targets/u2ire/resources')
+
     def test_get_connected(self):
         """Should make a request to get the currently selected target"""
         self.targets.api.request.return_value.status_code = 200
@@ -349,7 +403,19 @@ class TargetsTestCase(unittest.TestCase):
         self.targets.db.categories = [Category(id=1, name='Host')]
         out = self.targets.get_scope(slug='1392g78yr')
         self.targets.db.find_targets.assert_called_with(slug='1392g78yr')
-        self.targets.get_scope_host.assert_called_with(tgt)
+        self.targets.get_scope_host.assert_called_with(tgt, add_to_db=False)
+        self.assertEquals(out, 'HostScope')
+
+    def test_get_scope_for_host_add_to_db(self):
+        """Should get the scope for a Host when given Host information"""
+        self.targets.get_scope_host = MagicMock()
+        self.targets.get_scope_host.return_value = 'HostScope'
+        tgt = Target(category=1)
+        self.targets.db.find_targets.return_value = [tgt]
+        self.targets.db.categories = [Category(id=1, name='Host')]
+        out = self.targets.get_scope(slug='1392g78yr', add_to_db=True)
+        self.targets.db.find_targets.assert_called_with(slug='1392g78yr')
+        self.targets.get_scope_host.assert_called_with(tgt, add_to_db=True)
         self.assertEquals(out, 'HostScope')
 
     def test_get_scope_for_web(self):
@@ -361,7 +427,19 @@ class TargetsTestCase(unittest.TestCase):
         self.targets.db.categories = [Category(id=2, name='Web Application')]
         out = self.targets.get_scope(slug='1392g78yr')
         self.targets.db.find_targets.assert_called_with(slug='1392g78yr')
-        self.targets.get_scope_web.assert_called_with(tgt)
+        self.targets.get_scope_web.assert_called_with(tgt, add_to_db=False)
+        self.assertEquals(out, 'WebScope')
+
+    def test_get_scope_for_web_add_to_db(self):
+        """Should get the scope for a Host when given Web information"""
+        self.targets.get_scope_web = MagicMock()
+        self.targets.get_scope_web.return_value = 'WebScope'
+        tgt = Target(category=2)
+        self.targets.db.find_targets.return_value = [tgt]
+        self.targets.db.categories = [Category(id=2, name='Web Application')]
+        out = self.targets.get_scope(slug='1392g78yr', add_to_db=True)
+        self.targets.db.find_targets.assert_called_with(slug='1392g78yr')
+        self.targets.get_scope_web.assert_called_with(tgt, add_to_db=True)
         self.assertEquals(out, 'WebScope')
 
     def test_get_scope_host(self):
@@ -378,6 +456,22 @@ class TargetsTestCase(unittest.TestCase):
         self.targets.api.request.assert_called_with('GET', 'targets/213h89h3/cidrs?page=all')
         self.targets.api.request.return_value.json.assert_called()
 
+    def test_get_scope_host_add_to_db(self):
+        """Should get the scope for a Host"""
+        ips = ['1.1.1.1/32', '2.2.2.2/32']
+        self.targets.api.request.return_value.status_code = 200
+        self.targets.api.request.return_value.json.return_value = {
+            'cidrs': ips
+        }
+        self.targets.db.find_targets.return_value = [Target(slug='213h89h3', codename='SASSYSQUIRREL')]
+        out = self.targets.get_scope_host(codename='SASSYSQUIRREL', add_to_db=True)
+        self.assertEqual(ips, out)
+        self.targets.db.find_targets.assert_called_with(codename='SASSYSQUIRREL')
+        self.targets.api.request.assert_called_with('GET', 'targets/213h89h3/cidrs?page=all')
+        self.targets.api.request.return_value.json.assert_called()
+        self.targets.db.add_ips.assert_called_with([{'target': '213h89h3', 'ip': '1.1.1.1'},
+                                                    {'target': '213h89h3', 'ip': '2.2.2.2'}])
+
     def test_get_scope_no_provided(self):
         """Should get the scope for the currently connected target if none is specified"""
         self.targets.get_connected = MagicMock()
@@ -408,6 +502,29 @@ class TargetsTestCase(unittest.TestCase):
                                                     'asset/v1/organizations/93g8eh8/owners/listings/213h89h3/webapps')
         self.targets.api.request.return_value.json.assert_called()
 
+    def test_get_scope_web_add_to_db(self):
+        """Should get the scope for a Web Application"""
+        self.targets.api.request.return_value.status_code = 200
+        self.targets.build_scope_web_burp = MagicMock()
+        self.targets.build_scope_web_db = MagicMock()
+        web_results = [{
+            'web_results': 'yup these them!',
+            'owners': [{
+                'owner_uid': '213h89h3'
+            }],
+        }]
+        self.targets.api.request.return_value.json.return_value = web_results
+        tgt = Target(slug='213h89h3', organization='93g8eh8', codename='SASSYSQUIRREL')
+        self.targets.db.find_targets.return_value = [tgt]
+        out = self.targets.get_scope_web(codename='SASSYSQUIRREL', add_to_db=True)
+        self.assertEqual(web_results, out)
+        self.targets.build_scope_web_burp.assert_called_with(web_results)
+        self.targets.db.find_targets.assert_called_with(codename='SASSYSQUIRREL')
+        self.targets.api.request.assert_called_with('GET',
+                                                    'asset/v1/organizations/93g8eh8/owners/listings/213h89h3/webapps')
+        self.targets.api.request.return_value.json.assert_called()
+        self.targets.db.add_urls.assert_called_with(self.targets.build_scope_web_db.return_value)
+
     def test_get_unregistered(self):
         """Should query for unregistered targets"""
         results = [
